@@ -1,7 +1,7 @@
 """Utilizario de funciones usadas en los procesos de robotizacion
    con Python."""
 
-__version__ = "1.27"
+__version__ = "1.29"
 __author__ = "Jonathan Bolo"
 
 from ctypes.wintypes import PUINT
@@ -761,9 +761,11 @@ def sqlcmd(file_sql:StrOrPath,
     """
     
     sqlcmd_bin= '/opt/mssql-tools/bin/sqlcmd'
+    decode = 'utf-8'
     
     if os.name == 'nt':
         sqlcmd_bin = 'sqlcmd'
+        decode = 'utf-8-sig'
     
     file_sql = Path(file_sql)
     file_sql_log = Path(file_sql_log)
@@ -799,7 +801,7 @@ def sqlcmd(file_sql:StrOrPath,
         line = proc.stdout.readline()
         #log.debug(line.rstrip())
         if isinstance(line, bytes):
-            str_line = line.decode("utf-8")
+            str_line = line.decode(decode)
         else:
             str_line = line
         
@@ -809,10 +811,7 @@ def sqlcmd(file_sql:StrOrPath,
     file_sql_tmp.unlink()
 
     if file_sql_log.exists():
-        log.debug(open(file_sql_log, 
-                       "r", 
-                       encoding='utf-8', 
-                       errors='ignore').read())
+        log.debug(open(file_sql_log, "r", encoding=decode).read())
     
         if validate_error:
             if check_if_string_in_file(file_sql_log, "error"):
@@ -846,8 +845,11 @@ def bcp(table,
     """
     
     bcpcmd_bin= '/opt/mssql-tools/bin/bcp'
+    decode = 'utf-8-sig'
+    
     if os.name == 'nt':
         bcpcmd_bin = 'bcp'
+        decode = 'utf-8'
     
     file = Path(file)
     file_sql_log = Path(file_sql_log)
@@ -874,7 +876,7 @@ def bcp(table,
         line = proc.stdout.readline()
         #log.debug(line.rstrip())
         if isinstance(line, bytes):
-            str_line = line.decode("utf-8")
+            str_line = line.decode(decode)
         else:
             str_line = line
         
@@ -882,7 +884,7 @@ def bcp(table,
             log.debug(str_line)
 
     if file_sql_log.exists():
-        log.debug( open(file_sql_log, "r", encoding='utf-8').read() )
+        log.debug( open(file_sql_log, "r", encoding=decode).read() )
     
         if validate_error:
             if check_if_string_in_file(file_sql_log, "error"):
